@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2018 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -26,7 +26,7 @@ class ImportWizardFilterInfoGui : public MailImporter::FilterInfoGui
 {
 public:
     explicit ImportWizardFilterInfoGui(ManualImportMailPage *dlg, QWidget *parent);
-    ~ImportWizardFilterInfoGui();
+    ~ImportWizardFilterInfoGui() override;
 
     void setStatusMessage(const QString &status) override;
     void setFrom(const QString &from) override;
